<?php

switch ($messaggio) {

case "Vedi le prenotazioni":  			$messaggio = "Mira les reserves"; break;
case "presenti dal":  				$messaggio = "del"; break;
case "al":  					$messaggio = "al"; break;
case "Senza colori":  				$messaggio = "Sense color"; break;
case "Con colori":  				$messaggio = "En color"; break;
case "Tabella prenotazioni precedenti al":  	$messaggio = "Taula amb lesreserves anteriors al"; break;
case "Tabella prenotazioni successive al":  	$messaggio = "Taula amb lesreserves posteriors al"; break;
case "Tabella con tutte le prenotazioni":  	$messaggio = "Taula amb totes les reserves"; break;
case "Cognome_cliente":  			$messaggio = "Cognom_client"; break;
case "Data_iniziale":  				$messaggio = "Data_arribada"; break;
case "Data_finale":  				$messaggio = "Data_sortida"; break;
case "sett":  					$messaggio = "set."; break;
case "gio":  					$messaggio = "dies"; break;
case "Tariffa_completa":  			$messaggio = "Preu_total"; break;
case "Caparra":  				$messaggio = "Arres"; break;
case "Pagato":  				$messaggio = "Pagat"; break;
case "Da_pagare":  				$messaggio = "Saldo_pendent"; break;
case "Pers.":  					$messaggio = "Pers."; break;
case "Commento":  				$messaggio = "Comentari"; break;
case "Costo_uni.":  				$messaggio = "Supl_puntual"; break;
case "Costo_sett.":  				$messaggio = "Supl_setmanal"; break;
case "Costo_gio.":  				$messaggio = "Supl_diari"; break;
case "Soldi di prenotazioni cancellate":  	$messaggio = "Imports de reserves esborrades"; break;
case "Trasferito in cassa":  			$messaggio = "Transferit a caixa"; break;
case "RESTO":  					$messaggio = "RESTA"; break;
case "Sei sicuro di voler cancellare la spesa":	$messaggio = "Segur que cal esborrar la despesa"; break;
case "del valore di":  				$messaggio = "del valor de"; break;
case "Sei sicuro di voler cancellare l'entrata":	$messaggio = "Segur que cal esborrar l'ingrés"; break;
case "SI":  					$messaggio = "SÍ"; break;
case "NO":  					$messaggio = "NO"; break;
case "Entrata o spesa":  			$messaggio = "Ingrés o despesa"; break;
case "cacellata":  				$messaggio = "esborrada"; break;
case "Costo o spesa già cancellati":  		$messaggio = "Suplement o despesa ja esborrat"; break;
case "Tutte le spese del":  			$messaggio = "Relació de despeses del"; break;
case "nella cassa principale":  		$messaggio = "de la caixa principal"; break;
case "Natura_spesa":  				$messaggio = "Motiu_de_despesa"; break;
case "Importo":  				$messaggio = "Import"; break;
case "Inserita_da":  				$messaggio = "Inserit_per"; break;
case "Data_di_inserimento":  			$messaggio = "Data_d'inserció"; break;
case "Cancella":  				$messaggio = "Esborrar"; break;
case "Tutte le entrate del":  			$messaggio = "Relació d'ingressos del"; break;
case "Natura_entrata":  			$messaggio = "Motiu_de_l'ingrés"; break;
case "cancella":  				$messaggio = "esborra"; break;
case "entrata presa dalle prenotazioni":  	$messaggio = "entrada provinent de les reserves"; break;
case "Inserisci nuove spese o entrate":  	$messaggio = "Insereix nous ingressos o despeses"; break;
case "Storia entrate-uscite prenotazioni":  	$messaggio = "Historial de cobraments de les reserves"; break;
case "Sei sicuro di voler cancellare il costo aggiuntivo":	$messaggio = "Segur que cal esborrar el suplement"; break;
case "Il costo aggiuntivo":  			$messaggio = "El suplement"; break;
case "Il costo aggiuntivo è cambiato nel frattempo, non è stato cancellato":	$messaggio = "El suplement ha canviat durant l'operació, i no ha estat esborrat"; break;
case "è stato cancellato":  			$messaggio = "ha estat esborrat"; break;
case "I periodi sono stati aggiunti fino al":  	$messaggio = "Els períodes han estat afegits fins el"; break;
case "Tabella con periodi e relative tariffe del":	$messaggio = "Taula temporades i tarifes del"; break;
case "tariffa":  				$messaggio = "tarifa"; break;
case "Inizio_settimana":  			$messaggio = "Inici_setmana"; break;
case "Inizio_giorno":  				$messaggio = "Inici_dia"; break;
case "Fine_settimana":  			$messaggio = "Final_setmana"; break;
case "Fine_giorno":  				$messaggio = "Final_dia"; break;
case "Aggiungi periodi":  			$messaggio = "Afegir períodes"; break;
case "fino al mese":  				$messaggio = "fins el mes"; break;
case "Tabella con i costi aggiuntivi del":  	$messaggio = "Taula amb els sumplements del"; break;
case "Nome":  					$messaggio = "Nom"; break;
case "Tipo":  					$messaggio = "Tipus"; break;
case "Prezzo":  				$messaggio = "Preu"; break;
case "Da_assegnare":  				$messaggio = "A_assignar"; break;
case "finale":  				$messaggio = "puntual"; break;
case "Sempre":  				$messaggio = "Sempre"; break;
case "Su_richiesta":  				$messaggio = "A_petició"; break;
case "chidere_per_quanto_moltiplicare":  	$messaggio = "demanar_per_cuant_multiplicar"; break;
case "cosiderare_come_letti_aggiuntivi":  	$messaggio = "considera_com_llits_extra"; break;
case "settimanale":  				$messaggio = "setmanal"; break;
case "giornaliero":  				$messaggio = "diari"; break;
case "tutte":  				$messaggio = "totes"; break;
case "tutti":  				$messaggio = "tots"; break;
case "_le":  					$messaggio = "_les"; break;
case "_i":  					$messaggio = "_els"; break;
case "_settimane":  				$messaggio = "_setmanes"; break;
case "_giorni":  				$messaggio = "_dies"; break;
case "_meno_una":  				$messaggio = "_menys_una"; break;
case "con_n°_di_settimane":  			$messaggio = "amb_n°_de_setmanes"; break;
case "con_n°_di_giorni":  			$messaggio = "amb_n°_de_dies"; break;
case "_da_chiedere":  				$messaggio = "_a_demanar"; break;
case "% arrotondato_a_":  			$messaggio = "% arrodonit_a_"; break;
case "Caparre, commissioni e tasse del":  	$messaggio = "Arres, comissions i impostos del"; break;
case "Arrotondato_a":  				$messaggio = "Arrodonit_a"; break;
case "Vai alla pagina di inserzione prezzi":  	$messaggio = "Vés a la pàgina d'inserció de preus"; break;
case "chiamati":  				$messaggio = "anomenats"; break;
case "Cerca i clienti con cognome o email":  	$messaggio = "Cerca clients amb cognom o email"; break;
case "Tabella con tutti i clienti":  		$messaggio = "Taula amb tots els clients"; break;
case "pag. prec.":  				$messaggio = "pàg. ant."; break;
case "pag. succ.":  				$messaggio = "pàg. seg."; break;
case "Cognome":  				$messaggio = "Cognom"; break;
case "Nome":  					$messaggio = "Nom"; break;
case "Telefono":  				$messaggio = "Telèfon"; break;
case "Indirizzo":  				$messaggio = "Adreça"; break;
case "Città":  					$messaggio = "Ciutat"; break;
case "Nazione":  				$messaggio = "País"; break;
case "CAP":  					$messaggio = "Codi pos."; break;
case "Fax":  					$messaggio = "Fax"; break;
case "Data_di_nascita":  			$messaggio = "Data_de_neixament"; break;
case "2°telefono":  				$messaggio = "2° telèfon"; break;
case "Commento":  				$messaggio = "Comentari"; break;
case "Sei sicuro di voler <b>cancellare</b> la regola di assegnazione 2 per la":	$messaggio = "Segur que cal <b>esborrar</b> la regla d'assignació 2 per la"; break;
case "Sei sicuro di voler <b>cancellare</b> la regola di assegnazione 3 per la":	$messaggio = "Segur que cal <b>esborrar</b> la regla d'assignació 3 per la"; break;
case "Sei sicuro di voler <b>cancellare</b> la regola di assegnazione 4 per la":	$messaggio = "Segur que cal <b>esborrar</b> la regla d'assignació 4 per la"; break;
case "La regola di assegnazione è stata cancellata":	$messaggio = "La regla d'assignació ha estat esborrada"; break;
case "La regola di assegnazione è già stata cancellata":	$messaggio = "La regla d'assignació ja era esborrada"; break;
case "Tabella con le regole di assegnazione 1 del":	$messaggio = "Taula amb les regles d'assignació 1 del"; break;
case "Motivazione":  				$messaggio = "Motiu"; break;
case "Tabella con le regole di assegnazione 2 del":	$messaggio = "Taula amb les regles d'assignació 2 del"; break;
case "Tariffa":  				$messaggio = "Tarifa"; break;
case "Inserisci nuove regole":  		$messaggio = "Insereix noves regles"; break;
case "Il numero inserito esiste già":  		$messaggio = "El número inserit ja existeix"; break;
case "Continua":  				$messaggio = "Continua"; break;
case "Torna indietro":  			$messaggio = "Torna enrere"; break;
case "Casa":  					$messaggio = "Casa"; break;
case "Piano":  					$messaggio = "Pis"; break;
case "Capienza_massima":  			$messaggio = "Capacitat_màxima"; break;
case "Priorità":  				$messaggio = "Prioritat"; break;
case "Modifica":  				$messaggio = "Modificar"; break;
case "modifica":  				$messaggio = "modificar"; break;
case "Torna al menù principale":  		$messaggio = "Torna al menú principal"; break;
case "persone":  				$messaggio = "persones"; break;
case "s":  					$messaggio = "s"; break;
case "g":  					$messaggio = "d"; break;
case "Mostra":  				$messaggio = "Mostrar"; break;
case "Non_mostrare":  				$messaggio = "No_mostrar"; break;
case "Regole":  				$messaggio = "Regles"; break;
case "Tariffe abbinate":  			$messaggio = "Tarifas associades"; break;
case "pagine":  				$messaggio = "pàgines"; break;
case "I soldi pagati per la prenotazione":  	$messaggio = "L'import pagat per la reserva"; break;
case "a nome di":  				$messaggio = "a nom de"; break;
case "verranno cambiati da":  			$messaggio = "canviarà de"; break;
case "a":  					$messaggio = "a"; break;
case "saldo":  					$messaggio = "variació"; break;
case "Le prenotazioni <b>non sono state modificate</b> perchè sono cambiate nel frattempo":	$messaggio = "Les reserves <b>no han estat modificades</b> perquè han canviat durant l'operació"; break;
case "porre per le prenotazioni selezionate":  	$messaggio = "Passar les reserves seleccionades a"; break;
case "cambia":  				$messaggio = "Canviar"; break;
case "tutto pagato":  				$messaggio = "tot pagat"; break;
case "caparra pagata":  			$messaggio = "arres pagades"; break;
case "pagato niente":  				$messaggio = "res pagat"; break;
case "pagina":  				$messaggio = "pàgina"; break;
case "di":  					$messaggio = "de"; break;
case "la conferma":  				$messaggio = "la confimació"; break;
case "La prenotazione":  			$messaggio = "La reserva"; break;
case "verrà confermata":  			$messaggio = "serà confirmada"; break;
case "Data di inserimento":  			$messaggio = "Data d'inserció"; break;
case "Calcola il subtotale delle prenotazioni selezionate":	$messaggio = "Calcula el subtotal de les reserves seleccionades"; break;
case "selezionate precedentemente":  		$messaggio = "seleccionades amb anterioritat"; break;
case "Saldo totale":  				$messaggio = "Saldo total"; break;
case "l'anno":  				$messaggio = "l'any"; break;
case "dal database":  				$messaggio = "de la base de dades"; break;
case "<b style=\"color: red;\">ATTENZIONE</b>: premendo su <b>\"<i>Continua</i>\"</b>, tutti i dati riguardanti l'anno":	$messaggio = "<b style=\"color: red;\">ATENCIÓ</b>: en prémer  <b>\"<i>Continua</i>\"</b>, totes les dades de l'any"; break;
case "verranno <b>cancellati</b>":  		$messaggio = "seran <b>esborrades</b>"; break;
case "L'anno":  				$messaggio = "L'any"; break;
case "è stato cancellato dal batabase":  	$messaggio = "ha estat esborrat de la base de dades"; break;
case "Non è stato possibile cancellare l'anno":	$messaggio = "No ha estat possible esborrar l'any"; break;
case "dal database, controllare i permessi sulla cartella dati":	$messaggio = "de la base de dades, comprovar els permisos del directori dati"; break;
case "Profilo":  				$messaggio = "Perfil"; break;
case "Tabella con le regole di assegnazione 3 del":	$messaggio = "Taula amb les regles d'assignació 3 del"; break;
case "Utente":  				$messaggio = "Usuario"; break;
case "Periodi_permessi":  			$messaggio = "Períodes_permesos"; break;
case "unico":  					$messaggio = "puntual"; break;
case "fisso":  					$messaggio = "fix"; break;
case "percentuale su tariffa":  		$messaggio = "percentatge de la tarifa"; break;
case "percentuale su totale":  			$messaggio = "percentatge del total"; break;
case "varia_con_la_prenotazione":  		$messaggio = "canvia_amb_la_reserva"; break;
case "non_varia_con_la_prenotazione":  		$messaggio = "no_canvia_amb_la_reserva"; break;
case "_meno_l'ultima":  			$messaggio = "_menys_l'ltima"; break;
case "_meno_l'ultimo":  			$messaggio = "_menys_l'últim"; break;
case "_meno_la_prima":  			$messaggio = "_menys_la_primera"; break;
case "_meno_il_primo":  			$messaggio = "_menys_el_primer"; break;
case "giorni":  				$messaggio = "dies"; break;
case "moltiplicare_per_persone":  		$messaggio = "multiplicar_per_persones"; break;
case "moltiplicare_per_persone_totali":  	$messaggio = "multiplicar_per_persones_totals"; break;
case "moltiplicare_per_1":  			$messaggio = "multiplicar_per_1"; break;
case "massimo_":  				$messaggio = "màxim_"; break;
case "_nella_stessa_settimana":  		$messaggio = "_a_la_mateixa_setmana"; break;
case "_nello_stesso_giorno":  			$messaggio = "_a_el_mateix_dia"; break;
case "Prenotazione intera in":  		$messaggio = "Reserva sencera a"; break;
case "Parte della prentoazione in":  		$messaggio = "Part de la reserva a"; break;
case "Solo settimane della prenotazione in":  	$messaggio = "Només setmanes de la reserva en"; break;
case "Solo giorni della prenotazione in":  	$messaggio = "Només dies de la reserva a"; break;
case " o ":  					$messaggio = " o "; break;
case " a ":  					$messaggio = " a "; break;
case "_si":  					$messaggio = "_sí"; break;
case "_no":  					$messaggio = "_no"; break;
case "_e_":  					$messaggio = "_i_"; break;
case "associato_a_settimane_specifiche":  	$messaggio = "associat_a_setmanes_específiques"; break;
case "non_associato_a_settimane_specifiche":  	$messaggio = "no_associat_a_setmanes_específiques"; break;
case "associato_a_giorni_specifici":  		$messaggio = "associat_a_dies_específics"; break;
case "non_associato_a_giorni_specifici":  	$messaggio = "no_associat_a_dies_específics"; break;
case "modifica con prenotazione":  		$messaggio = "modifica amb reserva"; break;
case "percentuale su caparra":  		$messaggio = "percentatge de les arres"; break;
case "percentuale su resto caparra":  		$messaggio = "percentatge de la resta de les arres"; break;
case "Cancellati":  				$messaggio = "Esborrats"; break;
case "OK":  					$messaggio = "OK"; break;
case "Annulla":  				$messaggio = "Cancel·lar"; break;
case "Si è sicuri di voler <div style=\"display: inline; color: red;\"><b>cancellare":	$messaggio = "Segur que cal <div style=\"display: inline; color: red;\"><b>esborrar"; break;
case "clienti</b></div> che non sono associati a nessuna prenotazione e nessun pagamento":	$messaggio = "clients</b></div> que no siguin associats a cap reserva ni a cap pagament"; break;
case "Cancella i clienti senza prenotazioni":	$messaggio = "Esborrar els clients sense reserves"; break;
case "Metodo pagamento":  			$messaggio = "Mitjà pagament"; break;
case "Tariffe":  				$messaggio = "Tarifes"; break;
case "del":  					$messaggio = "del"; break;
case "Modifica tutti i campi della tabella":  	$messaggio = "Modificar tots els camps de la taula"; break;
case "Modifica i campi della tabella":  	$messaggio = "Modificar els camps de la taula"; break;
case "Applica i cambiamenti":  			$messaggio = "Aplicar els canvis"; break;
case "documento di tipo":  			$messaggio = "document tipus"; break;
case "visualizza":  				$messaggio = "Veure"; break;
case "Vedi tutte le prenotazioni":  		$messaggio = "Mirar totes les reserves"; break;
case "Tabella con le regole di assegnazione 4 del":	$messaggio = "Taula amb les regles d'assignació 4 del"; break;
case "Numero di persone":  			$messaggio = "Número de persones"; break;
case "assegna_se_":  				$messaggio = "assignar_si_"; break;
case "più_di_":  				$messaggio = "més_de_"; break;
case "meno_di_":  				$messaggio = "menys_de_"; break;
case "_giorni_da_inizio":  			$messaggio = "_dies_des_d'arribada"; break;
case "assegna_con_":  				$messaggio = "assignar_amb_"; break;
case "_o_più_prenotazioni":  			$messaggio = "_o_més_reserves"; break;
case "Modifica i prezzi":  			$messaggio = "Modificar els preus"; break;
case "<div style=\"display: inline; color: red;\">Non</div> è stato possibile inserire alcuni prezzi":	$messaggio = "<div style=\"display: inline; color: red;\">No</div> ha estat possible inserir alguns preus"; break;
case "I prezzi sono stati aggiornati":  	$messaggio = "Els preus han estat actualitzats"; break;
case "Tutte le prenotazioni":  			$messaggio = "Totes les reserves"; break;
case "Solo arrivi":  				$messaggio = "Només arribades"; break;
case "Solo partenze":  				$messaggio = "Només sortides"; break;
case "dal":  					$messaggio = "des de"; break;
case "Vedi":  					$messaggio = "Mirar"; break;
case "Tabella con tutti gli arrivi":  		$messaggio = "Taula d'arribades"; break;
case "Tabella con tutte le partenze":  		$messaggio = "Taula de sortides"; break;
case "prova ad importare i prezzi":  		$messaggio = "intenta importar els preus"; break;
case "giornalmente":  				$messaggio = "diariament"; break;
case "settimanalmente":  			$messaggio = "setmanalment"; break;
case "Origine":  				$messaggio = "Origen"; break;
case "Modifica come gruppo le prenotazioni mostrate in tabella":	$messaggio = "Modificar en bloc les reserves mostrades a la taula"; break;
case "Modifica come gruppo le prenotazioni selezionate":	$messaggio = "Modificar en bloc les reserves seleccionades"; break;
case "Statistiche":  				$messaggio = "Estadístiques"; break;
case "Anni":  					$messaggio = "Anys"; break;
case "Numero di prenotazioni per mese":  	$messaggio = "Quantitat de reserves per mes"; break;
case "Entrate dalle prenotazioni per mese":  	$messaggio = "Ingressos mensuals de les reserves"; break;
case "Entrate progressive dalle prenotazioni":	$messaggio = "Import acumulat total de les reserves"; break;
case "Numero di prenotazioni per origine":  	$messaggio = "Quantitat de reserves per origen"; break;
case "Entrate dalle prenotazioni per origine":	$messaggio = "Entradas de les reserves per origen"; break;
case "Cambia":  				$messaggio = "Canviar"; break;
case "Mesi":  					$messaggio = "Mesos"; break;
case "Entrate per metodo di pagamento":  	$messaggio = "Ingressos per mitjà de pagament"; break;
case "Descrizione":  				$messaggio = "Descripció"; break;
case "magazzino":  				$messaggio = "magatzem"; break;
case "inventario":  				$messaggio = "inventari"; break;
case "aggiungi":  				$messaggio = "afegir"; break;
case "Codice":  				$messaggio = "Codi"; break;
case "Beni inventario":  			$messaggio = "Béns inventari"; break;
case "Mancanti":  				$messaggio = "Manquen"; break;
case "bene eliminato":  			$messaggio = "Bé eliminat"; break;
case "bene aggiunto":  				$messaggio = "Bé afegit"; break;
case "magazzino eliminato":  			$messaggio = "magatzem eliminado"; break;
case "magazzino aggiunto":  			$messaggio = "magatzem afegit"; break;
case "Inventario importato":  			$messaggio = "Inventari importat"; break;
case "Importa l'invetario":  			$messaggio = "Importar l'inventari"; break;
case "dal magazzino":  				$messaggio = "des del magatzem"; break;
case "Incompatibilità":  			$messaggio = "Incompatibilitats"; break;
case "raggruppa":  				$messaggio = "agrupar"; break;
case "con email":  				$messaggio = "amb email"; break;
case "Importa":  				$messaggio = "Importar"; break;
case "per persona":  				$messaggio = "per persona"; break;
case "con meno di":  				$messaggio = "amb menys de"; break;
case "dall'inizio":  				$messaggio = "del començament"; break;
case "dalla fine":  				$messaggio = "del final"; break;
case "Mostra solo tariffe selezionate":  	$messaggio = "Mostrar només les tarifes seleccionades"; break;
case "mostra prezzi settimanali":  		$messaggio = "mostrar preus setmanals"; break;
case "mostra prezzi giornalieri":  		$messaggio = "mostrar preus diaris"; break;
case "periodi di":  				$messaggio = "períodes de"; break;
case "Valore":  				$messaggio = "Valor"; break;
case "della tariffa":  				$messaggio = "de la tarifa"; break;
case "piano":  					$messaggio = "pis"; break;
case "casa":  					$messaggio = "casa"; break;
case "documenti salvati":  			$messaggio = "documents desats"; break;
case "in":  					$messaggio = "a"; break;
case "numero":  				$messaggio = "número"; break;
case "nome file":  				$messaggio = "nom de l'arxiu"; break;
case "prenotazioni":  				$messaggio = "reserves"; break;
case "azione":  				$messaggio = "acción"; break;
case "anno":  					$messaggio = "any"; break;
case "elimina":  				$messaggio = "eliminar"; break;
case "fai l'upload del documento numero":  	$messaggio = "pujar el document número"; break;
case "fai l'upload":  				$messaggio = "pujar"; break;
case "si è sicuri di voler <b class=\"colred\">cancellare</b> il documento":	$messaggio = "Segur que cal <b class=\"colred\">esborrar</b> el document"; break;
case "cancellato":  				$messaggio = "esborrat"; break;
case "inviato":  				$messaggio = "enviat"; break;
case "Commissioni":  				$messaggio = "Comissions"; break;
case "Tasse":  					$messaggio = "Impostos"; break;
case "senza_commissioni":  			$messaggio = "sense_comissions"; break;
case "Documenti_salvati":  			$messaggio = "Documents_desats"; break;
case "TASSE":  					$messaggio = "IMPOSTOS"; break;
case "resto":  					$messaggio = "resta"; break;
case "cancella_periodi":  			$messaggio = "esborrar_períodes"; break;
case "Sei sicuro di voler cancellare le commissioni dal":	$messaggio = "Segur que cal esborrar les comissions des de el"; break;
case "sulla tariffa":  				$messaggio = "sobre la tarifa"; break;
case "Le commissioni sono state cancellate":  	$messaggio = "Les comissions han estat esborrades"; break;
case "Le commissioni sono cambiate nel frattempo, non sono state cancellate":	$messaggio = "Les comissions han canviat durant l'operació, no han estat esborrades"; break;
case "giorno":  				$messaggio = "dia"; break;
case "settimana":  				$messaggio = "setmana"; break;
case "costi agg.":  				$messaggio = "suplements"; break;
case "sconto":  				$messaggio = "descuento"; break;
case "Numero di prenotazioni per nazionalità del cliente titolare":	$messaggio = "Quantitat de reserves per nacionalitat del client titular"; break;
case "Entrate dalle prenotazioni per nazionalità del cliente titolare":	$messaggio = "Import de les reserves per nacionalitat del client titular"; break;
case "Prezzi con":  				$messaggio = "Preus amb"; break;
case "Prenotazioni anno corrente":  		$messaggio = "Reserves any en curs"; break;
case "con prenotazioni inserite":  		$messaggio = "amb reserves inserides"; break;
case "fino al":  				$messaggio = "fins"; break;
case "nella cassa chiamata":  			$messaggio = "a la caixa anomenada"; break;
case "Totale nella cassa principale":  		$messaggio = "Total a la caixa principal"; break;
case "Totale nella cassa":  			$messaggio = "Total a la caixa"; break;
case "Nuova cassa chiamata":  			$messaggio = "Nova caixa anomenada"; break;
case "Crea":  					$messaggio = "Crear"; break;
case "Una cassa chiamata":  			$messaggio = "Una caixa anomenada"; break;
case "è stata creata":  			$messaggio = "ha estat creada"; break;
case "Cassa chiamata":  			$messaggio = "Caixa anomenada"; break;
case "La cassa chiamata":  			$messaggio = "La caixa anomenada"; break;
case "è stata cancellata":  			$messaggio = "ha estat esborrada"; break;
case "Eventuali entrate e spese presenti in cassa non sono state cancellate":	$messaggio = "Hi ha ingressos i despeses que podrien no haver estat esborrats"; break;
case "Modifica i beni già inseriti":  		$messaggio = "Modificar els béns ja inserits"; break;
case "Modifica i beni":  			$messaggio = "Modificar els béns"; break;
case "I beni sono stati modificati":  		$messaggio = "Els bienes han estat modificats"; break;
case "p":  					$messaggio = "p"; break;
case "e combina":  				$messaggio = "i combinar"; break;
case "percentuale su fisso della tariffa":	$messaggio = "percentatge sobre import fix de la tarifa"; break;
case "percentuale su una persona della tariffa":	$messaggio = "percentatge d'una persona de la tarifa"; break;
case "non più di":  				$messaggio = "no més de"; break;
case "non più del numero di persone":  		$messaggio = "no més del número de persones"; break;
case "non più del numero totale di persone":  	$messaggio = "no més del número total de persones"; break;
case "meno":  					$messaggio = "menys"; break;
case "aggiungendo":  				$messaggio = "afegint-hi"; break;
case "Aggiungi":  				$messaggio = "Add"; break;
case "TOTALE":  				$messaggio = "TOTAL"; break;
case "percentuale":  				$messaggio = "percentage"; break;
case "Email":  					$messaggio = "Email"; break;
case "Sei sicuro di voler <b>cancellare</b> la regola di assegnazione 1 per la":	$messaggio = "Are you sure you want to <b>delete</b> the assignment rule 1 for"; break;
case "Verranno effettuati i seguenti cambiamenti":	$messaggio = "You will make this changes"; break;
case "Cliente":  				$messaggio = "Client"; break;
case "cliente":  				$messaggio = "client"; break;
case "clienti":  				$messaggio = "clients"; break;
case "carte di credito</b></div> associate a clienti che non hanno nessuna prenotazione nel futuro e nessuna prenotazione non pagata":	$messaggio = "credit cards</b></div> from clients without reservations in the future and without unpaid reservations"; break;
case "documento":  				$messaggio = "document"; break;
case "più di":  				$messaggio = "more than"; break;
case "prezzi importati":  			$messaggio = "prices imported"; break;
case "dalla tariffa":  				$messaggio = "from rate"; break;
case "Cancella le carte di credito di prenotazioni passate":	$messaggio = "Delete credit cards of past reservations"; break;
case "password per le carte di credito":  	$messaggio = "password for credit cards"; break;
case "Cancellate":  				$messaggio = "Deleted"; break;
case "carte di credito":  			$messaggio = "credit cards"; break;
case "password errata":  			$messaggio = "wrong password"; break;
case "Creare":  				$messaggio = "Create"; break;
case "persona":  				$messaggio = "person"; break;
case "chiusa":  				$messaggio = "closed"; break;
case "presenti in data":  			$messaggio = "present on"; break;
case "comprese partenze":  			$messaggio = "including departures"; break;
case "escludere_da_totale_percentuale":  	$messaggio = "exclude_from_percentage_total"; break;
case "":  		$messaggio = ""; break;
case "":  		$messaggio = ""; break;

} # fine switch ($messaggio)

?>